@@ -1,7 +1,6 @@
 use crate::date;
 use crate::db;
 
-use async_trait::async_trait;
 use chrono::offset::TimeZone;
 use chrono::prelude::*;
 use chrono::{Duration, Utc};
@@ -16,7 +15,8 @@ use teloxide::utils::markdown::{bold, escape};
 use teloxide::RequestError;
 
 pub enum TgResponse {
-    SuccessInsert,
+    SuccessInsert(String),
+    SuccessPeriodicInsert(String),
     FailedInsert,
     IncorrectRequest,
     QueryingError,
@@ -39,7 +39,8 @@ pub enum TgResponse {
 impl ToString for TgResponse {
     fn to_string(&self) -> String {
         let raw_text: String = match self {
-            Self::SuccessInsert => "Remember that!".to_string(),
+            Self::SuccessInsert(reminder_str) => format!("New reminder:\n{}", reminder_str),
+            Self::SuccessPeriodicInsert(reminder_str) => format!("New periodic reminder:\n{}", reminder_str),
             Self::FailedInsert => "Failed to create a reminder...".to_string(),
             Self::IncorrectRequest => "Incorrect request!".to_string(),
             Self::QueryingError => "Error occured while querying reminders...".to_string(),
@@ -157,7 +158,6 @@ impl GenericReminder for db::ReminderStruct {
     }
 }
 
-#[async_trait]
 impl GenericReminder for db::CronReminderStruct {
     fn get_time(&self) -> &NaiveDateTime {
         &self.time
